@@ -1,11 +1,11 @@
-from pyg_timeseries._decorators import compiled
-from pyg_timeseries._ewm import ewma, ewma_, ewmstd, ewmvar, ewmstd_, ewmrms, ewmrms_, ewmskew, ewmskew_, ewmcor, ewmcor_, ewmcorr, ewmcorr_, ewmvar_, ewmLR, ewmLR_, ewmGLM, ewmGLM_
+from pyg_timeseries._decorators import compiled, mask_nans, apply_along_first_axis
+from pyg_timeseries._ewm import ewma, ewma_, ewmstd, ewmvar, ewmstd_, ewmrms, ewmrms_, ewmskew, ewmskew_, ewmcor, ewmcor_, ewmcorr, ewmcorr_, ewmcovar, ewmcovar_, ewmvar_, ewmLR, ewmLR_, ewmGLM, ewmGLM_
 from pyg_timeseries._min import rolling_min, rolling_min_, expanding_min, expanding_min_
 from pyg_timeseries._max import rolling_max, rolling_max_, expanding_max, expanding_max_
 from pyg_timeseries._median import rolling_median, rolling_median_, expanding_median
 from pyg_timeseries._rank import rolling_rank, rolling_rank_, expanding_rank
-from pyg_timeseries._rolling import ffill, ffill_, bfill, fnna, diff, shift, ratio, rolling_mean, rolling_sum, rolling_rms, rolling_std, rolling_skew, \
-           diff_, shift_, ratio_, rolling_mean_, rolling_sum_, rolling_rms_, rolling_std_, rolling_skew_, v2na, na2v
+from pyg_timeseries._rolling import ffill, ffill_, ewfill, bfill, fnna, fnnz, diff, shift, ratio, rolling_mean, rolling_sum, rolling_rms, rolling_std, rolling_skew, \
+           diff_, shift_, ratio_, rolling_mean_, rolling_sum_, rolling_rms_, rolling_std_, rolling_skew_, v2na, na2v, buffer_, buffer
 from pyg_timeseries._stride import rolling_quantile, rolling_quantile_
 from pyg_timeseries._expanding import cumsum, cumprod, cumsum_, cumprod_, \
                 expanding_mean, expanding_sum, expanding_rms, expanding_std, expanding_skew, \
@@ -13,7 +13,13 @@ from pyg_timeseries._expanding import cumsum, cumprod, cumsum_, cumprod_, \
 from pyg_timeseries._ts import ts_std, ts_sum, ts_mean, ts_skew, ts_count, ts_min, ts_max, ts_rms, ts_median, ts_cor, \
                                             ts_interval, ts_std_, ts_sum_, ts_mean_, ts_skew_, ts_count_, ts_min_, ts_max_, ts_rms_, ts_cor_
                                             
-from pyg_timeseries._ewmxo import ewmxo, ewmxo_, ou_factor, ewmacd, ewmacd_, ewmvol_, ewmvol
+from pyg_timeseries._ewmxo import ou_factor, ewmacd, ewmacd_, ewmvol_, ewmvol
 from pyg_timeseries._xrank import xrank
 from pyg_timeseries._ewmcombine import ewmcombine, ewmcombined
-from pyg_timeseries._pandas import fnna_like
+from pyg_timeseries._pandas import fnna_like, reindex_3d
+from pyg_timeseries._opt import least_squares
+from pyg_timeseries._iter import ts_iterate
+from pyg_timeseries._linalg import riskparity, eigenvalues, eigenvectors, det, matmul
+from pyg_timeseries._bar import bar_r2
+from pyg_timeseries._track import minimize_tracking_error
+from pyg_timeseries._multibuffer import multibuffer
